function testJtemp
% testJtemp  Verify e = f(T) and T = g(e) routines for J type thermocouples
%
% Synopsis: testJtemp
%
% Input:  none
%
% Output:  Plot of errors in emf and temperature for round-trip
%          evaluation of calibration polynomials
%
% Author: Gerald Recktenwald, gerry@me.pdx.edu
%         Mechanical and Materials Engineering, Portland State University
%         Portland, Oregon, 2006-04-03

%  Use two round-trip tests.  e -> T -> e2, and T -> e -> T2

% --- Specify e, compute T, then reverse to get e2
e = linspace(-8000,42900,1000)*1e-6;    %  range of emf values
T = Jtemp(e);
e2 = emfJtype(T);
fprintf('norm(e-e2,inf) = %g\n',norm(e-e2,inf));
plot(e,e-e2,'.');
xlabel('e  (V)');   ylabel('Error:  e-e2  (V)');


% --- Check in reverse:
%     Specify T, compute e, then reverse to get T2
T = linspace(-209.9,759.9,1000);    %  range of T values
e = emfJtype(T);
T2 = Jtemp(e);
fprintf('norm(T-T2,inf) = %g\n',norm(T-T2,inf));
figure
plot(T,T-T2,'.');
xlabel('T  (C)');   ylabel('Error:  T-T2  (C)');
